<?php
/** Plautdietsch (Plautdietsch)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Purodha
 * @author Slomox
 * @author Wikipeeta
 */

$fallback = 'de';

$messages = array(
# User preference toggles
'tog-underline'               => 'Links unjastritje:',
'tog-highlightbroken'         => 'Links opp ladje Siede besondasch wiese <a href="" class="new">soo aus dit</a> (Alternative: soo aus dit<a href="" class="internal">?</a>).',
'tog-justify'                 => 'Tatjst em Blocksautz',
'tog-hideminor'               => 'Tjliene Endarunge ute latste Tiet nich wiese',
'tog-extendwatchlist'         => 'Moak dee Oppaussied-List jrata en wies aula Endarunge',
'tog-usenewrc'                => 'Betre Doastalinj (JavaScript es needich)',
'tog-numberheadings'          => 'Ewaschrefte automatisch numerere',
'tog-showtoolbar'             => 'Instrumente-Leist wiese (JavaScript)',
'tog-editondblclick'          => 'Siede mett Dobbeltklick beoabeide (JavaScript)',
'tog-editsection'             => 'Links tom Beoabeide von eenzelne Aufschnette wiese',
'tog-editsectiononrightclick' => 'Eenzelne Aufschnette mett eenem Rajsch-Klick beoabeide (JavaScript)',
'tog-showtoc'                 => 'Wies dee List mettem Enhault (fe Siede mett meea aus dree Ewaschrefte)',
'tog-rememberpassword'        => 'Login bewoare, dee Brucka blift aun disem Computer aunjemaldt',
'tog-previewontop'            => 'Wies Preview bowe em Beoabeide-Fensta',
'tog-showhiddencats'          => "Wies fe'stoakne Kategorien",

'underline-always' => 'Emma',
'underline-never'  => 'Nienijch',

# Dates
'sunday'        => 'Sindach',
'monday'        => 'Mondach',
'tuesday'       => 'Dinjsdach',
'wednesday'     => 'Medwäakj',
'thursday'      => 'Donnadach',
'friday'        => 'Friedach',
'saturday'      => 'Sinowent',
'sun'           => 'Sin',
'mon'           => 'Mon',
'tue'           => 'Din',
'wed'           => 'Med',
'thu'           => 'Don',
'fri'           => 'Fri',
'sat'           => 'Sow',
'january'       => 'Jaunwoa',
'february'      => 'Feebawoa',
'march'         => 'Moats',
'april'         => 'Aprell',
'may_long'      => 'Mei',
'june'          => 'Jüni',
'july'          => 'Jüli',
'august'        => 'August',
'september'     => 'Septamba',
'october'       => 'Oktooba',
'november'      => 'Nowamba',
'december'      => 'Deetsamba',
'january-gen'   => 'Jaunwoa',
'february-gen'  => 'Feebawoa',
'march-gen'     => 'Moats',
'april-gen'     => 'Aprell',
'may-gen'       => 'Mei',
'june-gen'      => 'Jüni',
'july-gen'      => 'Jüli',
'august-gen'    => 'August',
'september-gen' => 'Septamba',
'october-gen'   => 'Oktooba',
'november-gen'  => 'Nowamba',
'december-gen'  => 'Deetsamba',
'jan'           => 'Jau',
'feb'           => 'Fee',
'mar'           => 'Moa',
'apr'           => 'Apr',
'may'           => 'Mei',
'jun'           => 'Jun',
'jul'           => 'Jul',
'aug'           => 'Aug',
'sep'           => 'Sep',
'oct'           => 'Okt',
'nov'           => 'Now',
'dec'           => 'Dez',

# Categories related messages
'pagecategories'           => '{{PLURAL:$1|Kategorie|Kategorien}}',
'category_header'          => 'Siede in Kategorie "$1"',
'category-media-header'    => 'Bilda in Kategorie "$1"',
'hidden-categories'        => "{{PLURAL:$1|Fe'stoakne Kategorie|Fe'stoakne Kategorien}}",
'hidden-category-category' => "Fe'stoakne Kategorien",

'about'         => 'Äwa',
'newwindow'     => '(got in en nie Fensta op)',
'cancel'        => 'Aufbräakje',
'moredotdotdot' => 'Mea...',
'mypage'        => 'Miene Sied',
'mytalk'        => 'Miene Beredsied',
'anontalk'      => 'Beredsied fe dise IP',
'navigation'    => 'Navigatioon',
'and'           => '&#32;onn',

# Cologne Blue skin
'qbfind'         => 'finje',
'qbedit'         => 'Endre',
'qbpageoptions'  => 'Dise Sied',
'qbmyoptions'    => 'Miene Siede',
'qbspecialpages' => "Opp'poate Siede",

'errorpagetitle'   => 'Fäla',
'returnto'         => 'Trigj no $1.',
'tagline'          => 'Fonn {{SITENAME}}',
'help'             => 'Help',
'search'           => 'Setje',
'searchbutton'     => 'Setje',
'go'               => 'Go',
'searcharticle'    => 'Sied',
'history'          => "Siedeje'schijchte",
'history_short'    => 'Jeschicht',
'updatedmarker'    => 'fresch jemoakt',
'info_short'       => 'Informatioon',
'printableversion' => 'Drekdoastalinj',
'permalink'        => 'Bestendja Link',
'print'            => 'Drek',
'edit'             => 'Endre',
'create'           => 'Moak',
'editthispage'     => 'Endre dise Sied',
'create-this-page' => 'Moak dise Sied',
'delete'           => 'Lasche',
'deletethispage'   => 'Dise Sied lasche',
'protect'          => "be'schutse",
'newpage'          => 'Nie Sied',
'talkpage'         => 'Beräd de Sied',
'talkpagelinktext' => 'Beredsied',
'specialpage'      => 'Spezialsied',
'personaltools'    => 'Perseenliche Instrumente',
'postcomment'      => 'Kommentar moake',
'talk'             => 'Beredsied',
'views'            => 'Aunsechte',
'toolbox'          => 'Instrumente',
'userpage'         => 'Brucka-Sied',
'projectpage'      => 'Meta-Sied',
'imagepage'        => 'Datei-Sied',
'mediawikipage'    => 'Enhault wiese',
'templatepage'     => 'Sied mett Dokumentenvorlagen wiese',
'viewhelppage'     => 'Help-Sied wiese',
'categorypage'     => 'Kategorie-Sied wiese',
'viewtalkpage'     => 'Diskussioon',
'otherlanguages'   => 'In aundre Sproake',
'redirectedfrom'   => '(wieda jeleidt von $1)',
'redirectpagesub'  => 'Sied tom Wiedaleide',
'lastmodifiedat'   => "Dise Sied word aum $1, klock $2 daut latzte Mol je'endat.",
'protectedpage'    => 'Sied mett besondrem Schutz',
'jumpto'           => 'Sprinj no:',
'jumptonavigation' => 'Navigatioon',
'jumptosearch'     => 'Setje',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => 'Äwa {{SITENAME}}',
'aboutpage'            => 'Project:Äwa',
'copyright'            => 'Enhault es to habe unja $1.',
'currentevents'        => 'Aktuelle Sache',
'currentevents-url'    => 'Project:Aktuelle Sache',
'disclaimers'          => 'Impressum',
'disclaimerpage'       => 'Project:Impressum',
'edithelp'             => 'Help tom Beoabeide',
'edithelppage'         => 'Help:Help tom Beoabeide',
'helppage'             => 'Help:Enhault',
'mainpage'             => 'Hauptsied',
'mainpage-description' => 'Hauptsied',
'policy-url'           => 'Project:Policy',
'portal'               => 'Jemeenschauftsportal',
'portal-url'           => 'Project:Jemeenschauftsportal',
'privacy'              => 'Doteschutz',
'privacypage'          => 'Project:Doteschutz',

'badaccess'        => 'Nich utretjende Rajchte',
'badaccess-group0' => 'Du hast nich daut needje Rajcht fe dise Aktioon.',

'versionrequired' => 'Versioon $1 von MediaWiki es needich',

'retrievedfrom'           => 'Von "$1"',
'youhavenewmessages'      => 'Dü hast $1 ($2).',
'newmessageslink'         => 'Niee Norechte',
'newmessagesdifflink'     => "Latztet mol je'endat",
'youhavenewmessagesmulti' => 'Du hast niee Norechte bie $1',
'editsection'             => 'Beoabeide',
'editold'                 => 'endre',
'editsectionhint'         => 'Aufschnett beoabeide: $1',
'toc'                     => 'Enhault',
'showtoc'                 => 'wiese',
'hidetoc'                 => "fe'stäakje",
'thisisdeleted'           => '$1 seene ooda wada trajchtmoake?',
'viewdeleted'             => '$1 wiese?',
'feed-invalid'            => 'Abonnement-Typ es nich rechtich.',
'feed-unavailable'        => 'Daut jefft tjeene Feeds',
'site-rss-feed'           => '$1 RSS-Feed',
'site-atom-feed'          => '$1 Atom-Feed',
'page-rss-feed'           => 'RSS Feed fe "$1"',
'page-atom-feed'          => 'Atom-Feed fe "$1"',
'feed-atom'               => 'Atom',
'red-link-title'          => '$1 (Sied noch nich jemoakt)',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'      => 'Sied',
'nstab-user'      => 'Bruckasied',
'nstab-media'     => 'Media',
'nstab-special'   => 'Besondre Sied
Spezial',
'nstab-project'   => 'Portalsied',
'nstab-image'     => 'Datei',
'nstab-mediawiki' => 'Norejcht',
'nstab-help'      => 'Helpsied',
'nstab-category'  => 'Kategorie',

# Main script and global functions
'nosuchaction'      => 'Soone Aktioon jefft et nich',
'nosuchactiontext'  => 'Dee Aktioon von dise URL woat von MediaWiki nich unjastett.',
'nosuchspecialpage' => 'Soone Spezialsied jefft et nich',
'nospecialpagetext' => '<strong>Dee oppjeroopde Spezialsied jefft et nich.</strong>

Aula bruckboare Spezialsiede send bie [[Special:SpecialPages|{{int:specialpages}}]] to finje.',

# General errors
'error'           => 'Fehla',
'databaseerror'   => 'Fehla enne Dotebank',
'dberrortext'     => 'Daut gauf een Syntaxfehla biem Opproope vonne Dotebank.
Doa kaun een Probleem enne Software senne.
Daut latzte Opproope vonne Dotebank we:
<blockquote><tt>$1</tt></blockquote>
ute Funktioon "<tt>$2</tt>".
MySQL mald dem Fehla "<tt>$3: $4</tt>".',
'laggedslavemode' => 'Oppjepausst: Dee jewesne Sied es nich onbedinjt dee latzte Versioon.',
'readonly'        => 'Dotebank es jeschlote',
'enterlockreason' => 'Nan bitte een Grunt doafea, wurom dee Dotebank jeschlote saul en saj, woolang daut onjefea diere saul',
'missing-article' => 'Dee Database haft nich dem Tatjst von eene Sied jefunge, woone hee haud finje sullt, mettem Nome "$1" $2.

Dit tjemm jeweenlich soo, wan een oola nich jelaschda Link jebruckt worde es.

Wan daut nich soo es, dan es doa vleicht een Fehla enne Software.
Bitte schriew eene Notiz aun [[Special:ListUsers/sysop|administrator]], en lot dem dee URL weete.',
'badtitle'        => 'Schlajchta Titel',
'viewsourcefor'   => 'fer $1',

# Login and logout pages
'yourname'                => 'Bruckanome:',
'yourpassword'            => 'Pauswot:',
'nav-login-createaccount' => 'Aunmalde',
'loginprompt'             => 'Tom Aunmalde motte Cookies bie {{SITENAME}} aktiviet senne.',
'userlogin'               => 'Aunmalde',
'logout'                  => 'Rut hia',
'userlogout'              => 'Rut hia',
'notloggedin'             => 'Nich aunjemaldt',
'nologin'                 => "Hast tjeen Bruckakonto? '''$1'''.",
'nologinlink'             => 'Nieet Bruckakonto moake',
'createaccount'           => 'Bruckakonto moake',
'gotaccount'              => "Hast aul een Bruckakonto? '''$1'''.",
'gotaccountlink'          => 'Aunmalde',
'createaccountmail'       => 'Ewa Email',
'badretype'               => 'Dee beid Pauswed stemme nich ewaeen.',
'userexists'              => 'Dem Bruckanome haft aul wea.
Bitte nemm eenen aundren.',
'loginlanguagelabel'      => 'Sproak: $1',

# Edit page toolbar
'media_tip' => 'Datei-Link',

# Edit pages
'summary'              => 'Toofotinj:',
'subject'              => 'Teema:',
'minoredit'            => 'Dit es eene tjliene Endanis.',
'watchthis'            => 'Paus op dise Sied op',
'savearticle'          => 'Sied bewoare',
'preview'              => 'Preview',
'showpreview'          => 'Wies Preview',
'showlivepreview'      => 'Live-Preview',
'showdiff'             => 'Endanisse wiese',
'anoneditwarning'      => "'''Paus opp:''' Du best nich aunjemaldt. Diene IP-Adras woat enne Versioonsjeschicht oppbewoat en es emma to seene.",
'missingsummary'       => "'''Dentj draun:''' Du hast tjeene Toopfotinj jemoakt. Wan du wada opp Bewoare klickst, woat diene Endanis ohne Toopfotinj ewanohme.",
'missingcommenttext'   => 'Bitte schriew eene korte Toopfotinj.',
'missingcommentheader' => "'''Dentj draun:''' Du hast tjeen Teema em Plautz \"Teema\" jeschrewe. Wan du wada opp Sied Bewoare klickst, woat diene Oabeit ohne Teema bewoat.",
'summary-preview'      => 'Toopfotinj-Preview:',
'subject-preview'      => 'Teema-Preview:',
'blockedtitle'         => 'Dis Brucka es jeblockt.',
'newarticle'           => '(Nie)',
'template-protected'   => "(be'schutst)",

# History pages
'revisionasof'  => 'Versioon von $1',
'revision-info' => 'Versioon von $1 von $2',
'cur'           => 'dise',
'last'          => 'latste',
'page_first'    => 'easchte',
'page_last'     => 'latste',

# Revision feed
'history-feed-item-nocomment' => '$1 omm $2',

# Revision deletion
'rev-delundel' => 'wies/vestopp',

# Diffs
'lineno'   => 'Lien $1:',
'editundo' => 'trigjsate',

# Search results
'searchresults'             => 'Setj Resultaute',
'searchresults-title'       => 'Setj Resultaute fe "$1"',
'searchsubtitle'            => 'Du sochst \'\'\'[[:$1]]\'\'\' ([[Special:Prefixindex/$1|all pages starting with "$1"]]{{int:pipe-separator}}[[Special:WhatLinksHere/$1|all pages that link to "$1"]])',
'prevn'                     => '{{PLURAL:$1|$1}} ferhäa',
'nextn'                     => 'näakjste {{PLURAL:$1|$1}}',
'viewprevnext'              => 'Tjitj ($1 {{int:pipe-separator}} $2) ($3)',
'searchhelp-url'            => 'Help:Enhault',
'search-result-size'        => '$1 ({{PLURAL:$2|1 Wot|$2 Wed}})',
'search-mwsuggest-enabled'  => 'mett Veaschlag',
'search-mwsuggest-disabled' => 'Tjeen Veaschlag',
'powersearch'               => 'Bätre Sääk',
'powersearch-legend'        => 'Betret Setje',
'powersearch-field'         => 'Setj no',

# Preferences page
'preferences'          => 'Ennstalinje',
'mypreferences'        => 'Miene Ennstalinje',
'youremail'            => 'Email:',
'username'             => 'Bruckanome:',
'uid'                  => 'Brucka-ID:',
'prefs-memberingroups' => 'Mettjliet von {{PLURAL:$1|group|groups}}:',
'yourrealname'         => 'Ajchta Nome:',
'yourlanguage'         => 'Sproak:',

# Recent changes
'nchanges'        => '$1 {{PLURAL:$1|Endaniss|Endanisse}}',
'recentchanges'   => 'Nieste Endanisse',
'rcshowhideminor' => '$1 kjleene Endanisse',
'rcshowhideanons' => '$1 nomeloose Bruckasch',
'rcshowhidemine'  => '$1 miene Endanisse',
'rclinks'         => 'Wies de latste $1 Endanisse in de latste $2 Doag<br />$3',
'diff'            => 'Unjascheet',
'hist'            => 'Jeschicht',
'hide'            => "Fe'stäakje",
'show'            => 'Wiese',
'minoreditletter' => 'k',
'newpageletter'   => 'N',
'boteditletter'   => 'b',

# Recent changes linked
'recentchangeslinked'          => 'Endarunge aun velinkte Siede',
'recentchangeslinked-feed'     => 'Endarunge aun velinkte Siede',
'recentchangeslinked-toolbox'  => 'Endarunge aun velinkte Siede',
'recentchangeslinked-title'    => 'Endarunge aun Siede, woone von "$1" velinkt send',
'recentchangeslinked-backlink' => '← $1',
'recentchangeslinked-noresult' => 'Em utjesochten Tietrum es aun dee velinkte Siede nuscht aundasch jemoakt worde.',
'recentchangeslinked-summary'  => "Dit es eene List mette latzte Endarunge aune velinkte Siede (ooda bie Kategorien von Mettjlieda von dise Kategorie). Dee Siede opp diene [[Special:Watchlist|your watchlist]] woare '''fat''' jewese.",
'recentchangeslinked-page'     => 'Siednome:',
'recentchangeslinked-to'       => 'Wies Endarunge opp Siede, woone mett dise Sied velinkt send',

# Upload
'upload'                     => 'Nopplode',
'uploadbtn'                  => 'Datei nopplode',
'reuploaddesc'               => 'Stopp Nopplode en tridj no dee Nopplode-Sied',
'uploadnologin'              => 'Nich aunjemaldt',
'uploadnologintext'          => 'Du mottst [[Special:UserLogin|aunjemaldt senne]], wan Dateie nopplode wellst.',
'upload_directory_missing'   => 'Dee Nopplode-Vetetjnis ($1) fehlt en kunn vom Webserver nich jemoakt woare.',
'upload_directory_read_only' => 'Dee Webserver haft tjeene Schriewrajchte fe daut Nopplode-Vetetjnis ($1).',
'uploaderror'                => 'Fehla biem Nopplode',

# Special:ListFiles
'listfiles_user' => 'Brucker',

# File description page
'file-anchor-link'    => 'Datei',
'filehist'            => 'Dokument-Jeschicht',
'filehist-datetime'   => 'Tiet',
'filehist-user'       => 'Brucker',
'filehist-dimensions' => 'Moten',
'imagelinks'          => 'Links',

# MIME search
'mimesearch' => 'MIME-Säkj',

# List redirects
'listredirects' => 'Wiedawiesinje wiese',

# Random page
'randompage' => 'toofallijche Sied',

# Statistics
'statistics' => 'Statistik',

'doubleredirects' => 'Dobbelt Wiedawiesinje',

'brokenredirects' => "Ka'put Wiedawiesinj",

# Miscellaneous special pages
'nbytes'            => '$1 {{PLURAL:$1|Byte|Bytes}}',
'nlinks'            => '$1 {{PLURAL:$1|Link|Links}}',
'wantedpages'       => 'Needijche Siede',
'shortpages'        => 'Korte Siede',
'longpages'         => 'Lange Siede',
'protectedpages'    => "Be'schutste Siede",
'newpages'          => 'Nie Siede',
'newpages-username' => 'Bruckernome:',
'ancientpages'      => 'Ellste Siede',

# Special:Log
'specialloguserlabel'  => 'Brucker:',
'speciallogtitlelabel' => 'Tietel:',
'all-logs-page'        => 'Aule Berejchte',

# Special:AllPages
'allpages'       => 'Aule Siede',
'alphaindexline' => '$1 bott $2',
'allpagesfrom'   => 'Wies Siede fonn auf:',
'allarticles'    => 'Aule Siede',

# Watchlist
'mywatchlist'   => 'Miene Oppaussied',
'addedwatch'    => "No Oppausssied bieje'done",
'watch'         => 'Oppausse',
'watchthispage' => 'Op dise Sied oppausse',
'unwatch'       => 'Nijch mea oppausse',

# Displayed when you click the "watch" button and it is in the process of watching
'watching'   => 'Oppausse...',
'unwatching' => 'Nijch mea oppausse......',

# Delete
'deleteotherreason'     => 'Aundra Grunt:',
'deletereasonotherlist' => 'Aundre Grunt',

# Rollback
'rollbacklink' => 'trigj rolle',

# Protect
'protectexpiry'          => 'Ütgontiet:',
'protect-expiry-options' => '2 Stunde:2 hours,1 Dach:1 day,1 Wäakj:1 week,2 Wäakje:2 weeks,1 Moonat:1 month,3 Moonate:3 months,6 Moonate:6 months,1 Joa:1 year,one Enj:infinite',
'restriction-type'       => "Er'laubniss:",

# Namespace form on various pages
'namespace'      => 'Nomerum:',
'blanknamespace' => '(Haupt)',

# Contributions
'mycontris' => 'Mien Biedroage',
'uctop'     => '(bowe)',
'month'     => 'Fonn Moonat (onn ferdäm):',
'year'      => 'Fonn Joa (onn ferdäm):',

'sp-contributions-talk' => 'Beredsied',

# What links here
'whatlinkshere'          => 'Links opp dise Sied',
'whatlinkshere-title'    => 'Siede, woone opp "$1" eenen Link habe',
'whatlinkshere-page'     => 'Sied:',
'whatlinkshere-backlink' => '← $1',
'linkshere'              => "Dee neachste Siede habe eenen Link opp '''[[:$1]]''':",
'nolinkshere'            => "Tjeene Sied haft eenen Link opp '''[[:$1]]'''.",
'nolinkshere-ns'         => "Tjeene Siede habe eenen Link opp '''[[:$1]]''' em utjesochten Nomesrum.",
'isredirect'             => 'Wiedaleid-Sied',
'istemplate'             => 'Vealoag-Enbinje (Inklusioon)',
'isimage'                => 'Dotei-Link',
'whatlinkshere-links'    => '← Links',

# Block/unblock
'ipboptions'       => '2 Stunde:2 hours,1 Dach:1 day,3 Doag:3 days,1 Wäakj:1 week,2 Wäakje:2 weeks,1 Moonat:1 month,3 Moonate:3 months,6 Moonate:6 months,1 Joa:1 year,one Enj:infinite',
'blocklink'        => 'blocke',
'unblocklink'      => 'frie jewe',
'change-blocklink' => 'Daut Blocke endre',
'contribslink'     => 'Biedrachs',
'autoblocker'      => 'Automatisch jeblockt, wiels diene IP-Adras soo es aus bie "[[User:$1|$1]]".
Dee Grunt es: "$2"',
'blocklogpage'     => 'Block-Logbok',
'blocklogentry'    => 'haft [[$1]] jeblockt fe dee Tiet $2 $3',
'reblock-logentry' => "haft dee Block-Enstalinj fe [[$1]] je'endat fe dee Tiet $2 $3",

# Move page
'newtitle'   => 'No nie Tietel:',
'move-watch' => 'Opp dise Sied oppausse',
'movereason' => 'Grunt:',
'revertmove' => 'trigj dreie',

# Namespace 8 related
'allmessages' => "Sis'teem-Norejchte",

# Thumbnails
'thumbnail-more' => 'Vejratre',

# Tooltip help for the actions
'tooltip-pt-userpage'             => 'Diene Bruckersied',
'tooltip-pt-mytalk'               => 'Diene Beredsied',
'tooltip-pt-preferences'          => 'Miene Ennstalinje',
'tooltip-pt-watchlist'            => 'List fonn Siede, op de du oppausst, waut sikj endat',
'tooltip-pt-mycontris'            => 'List fonn diene Biedroage',
'tooltip-pt-login'                => 'Aunmalde wudd scheen senne, es oba nich onbedinjt needich.',
'tooltip-pt-anonlogin'            => 'Aunmalde wudd scheen senne, es oba nich onbedinjt needich.',
'tooltip-pt-logout'               => 'Rut hia',
'tooltip-ca-talk'                 => 'Diskussioon ewa dem Ennhault vonne Sied',
'tooltip-ca-edit'                 => 'Du kaunst dise Sied beoabeide. Bitte verrem Bewoare dee Eschtmolseene-Funktioon brucke.',
'tooltip-ca-addsection'           => 'Eenen Kommentar to dise Diskussioon biedroage.',
'tooltip-ca-viewsource'           => 'Dise Sied blifft bewoat. Du kaunst die dem Tjwaltatjst aunseene.',
'tooltip-ca-history'              => 'Ellre Versioone von dise Sied.',
'tooltip-ca-protect'              => "Dise Sied be'schutse",
'tooltip-ca-delete'               => 'Dise Sied lasche',
'tooltip-ca-undelete'             => 'Moak dee Sied wada soo, aus see verrem Lasche utleet.',
'tooltip-ca-move'                 => 'Dise Sied veschuwe',
'tooltip-ca-watch'                => 'Dise Sied bie miene Oppaussied-Liste doatoo doone',
'tooltip-ca-unwatch'              => 'Dise Sied vonne perseenliche Oppaussied-Liste fot nehme',
'tooltip-search'                  => 'Setje op {{SITENAME}}',
'tooltip-search-go'               => 'Go opp dee Sied, woone jenau disem Nome haft',
'tooltip-search-fulltext'         => 'Setj no Siede mett soonem Tatjst',
'tooltip-n-mainpage'              => 'Besäkj de Hauptsied',
'tooltip-n-mainpage-description'  => 'Besetj dee Hauptsied',
'tooltip-n-portal'                => 'Ewa daut Portal, waut du doone kaunst, woo waut to finje es',
'tooltip-n-currentevents'         => 'Hinjagruntinformatioone ewa aktuelle Sache finje',
'tooltip-n-recentchanges'         => 'List mette latste Endanisse em Wiki.',
'tooltip-n-randompage'            => 'Wies eene toofaulje Sied',
'tooltip-n-help'                  => 'Helpsied wiese',
'tooltip-t-whatlinkshere'         => 'List mett aula Siede, woone hia han wiese',
'tooltip-t-recentchangeslinked'   => 'Latste Endanisse aun Siede, woone mett dise eenen Link habe',
'tooltip-feed-rss'                => 'RSS-Feed fe dise Sied',
'tooltip-feed-atom'               => 'Atom-Feed fe dise Sied',
'tooltip-t-contributions'         => 'List mett Biedroag von disem Brucka wiese',
'tooltip-t-emailuser'             => 'Eene Email aun disem Brucka schetje',
'tooltip-t-upload'                => 'Dateie nopplode',
'tooltip-t-specialpages'          => 'List mett aula Spezialsiede',
'tooltip-t-print'                 => 'Dretjboare Versioon von dise Sied',
'tooltip-t-permalink'             => 'Bestendja Link no dise Versioon vonne Sied',
'tooltip-ca-nstab-main'           => 'Sied-Ennhault wiese',
'tooltip-ca-nstab-user'           => 'Bruckasied wiese',
'tooltip-ca-nstab-media'          => 'Mediensied wiese',
'tooltip-ca-nstab-special'        => "Dit es eene Spezialsied. Dee kaun nich je'endat woare.",
'tooltip-ca-nstab-project'        => 'Portalsied wiese',
'tooltip-ca-nstab-image'          => 'Datei-Sied wiese',
'tooltip-ca-nstab-mediawiki'      => 'Systeem-Tatjst wiese',
'tooltip-ca-nstab-template'       => 'Vorlage/Template wiese',
'tooltip-ca-nstab-help'           => 'Helpsied wiese',
'tooltip-ca-nstab-category'       => 'Kategorie-Sied wiese',
'tooltip-minoredit'               => "Dise Ve'endrung aus tjlien markiere",
'tooltip-save'                    => 'Endarunge bewoare',
'tooltip-preview'                 => 'Verut-Aunsecht vonne Endarunge aun dise Sied. Bitte verrem Bewoare brucke!',
'tooltip-diff'                    => 'Endarunge aum Tajst wiese',
'tooltip-compareselectedversions' => 'Unjascheede wiese tweschen dee beid jewehlde Versioone von dise Sied.',
'tooltip-watch'                   => 'Doo dise Sied bie diene Oobacht-List doatoo',
'tooltip-recreate'                => 'Moak dee Sied wada fresh, uck wan se wea jelascht haft.',
'tooltip-upload'                  => 'Nopplode aunfange',
'tooltip-rollback'                => '"Rollback" dreit dee Endarung(e) von dise Sied mett eenem Klick wada tridj bettem latsten Biedrach.',
'tooltip-undo'                    => 'Moakt bloos dise eene Endarung tridj en wiest daut Resultaut en eenem Eschtmolseene-Fensta, doamett enne Toopfotinj een Grunt jenant woare kaun.',

# Stylesheets
'common.css'      => '/* CSS opp dise Sted woat opp aula Skins wirtje */',
'standard.css'    => '/* CSS opp dise Sted wirtjt opp dem Standard-Skin */',
'nostalgia.css'   => '/* CSS opp dise Sted wirtjt opp daut Nostalgia-Skin */',
'cologneblue.css' => '/* CSS opp dise Sted wirtjt opp daut Keloonsch-Blau-Skin */',
'monobook.css'    => '/* CSS opp dise Sted wirtjt opp daut Monobook-Skin */',
'myskin.css'      => '/* CSS opp dise Sted wirtjt opp daut MySkin-Skin */',
'chick.css'       => '/* CSS opp dise Sted wirtjt opp daut Chick-Skin */',
'simple.css'      => '/* CSS opp dise Sted wirtjt opp daut Simple-Skin */',
'modern.css'      => '/* CSS opp dise Sted wirtjt opp daut Modern-Skin */',
'print.css'       => '/* CSS opp dise Sted woat daut Utkome vom Dretje aundasch moake */',

# Scripts
'common.js'      => '/* Daut neachste JavaScript woat fe aula Brucka jelode. */',
'standard.js'    => '/* Daut neachste JavaScript woat fe Brucka mett Standard-Skin jelode. */',
'nostalgia.js'   => '/* Daut neachste JavaScript woat fe Brucka mett Nostalgie-Skin jelode. */',
'cologneblue.js' => '/* Daut neachste JavaScript woat fe Brucka mett Keloonsch-Blau-Skin jelode */',
'monobook.js'    => '/* Daut neachste JavaScript woat fe Brucka mett Monobook-Skin jelode */',
'myskin.js'      => '/* Daut neachste JavaScript woat fe Brucka mett MySkin-Skin jelode */',
'chick.js'       => '/* Daut neachste JavaScript woat fe Brucka mett Chick-Skin jelode */',
'simple.js'      => '/* Daut neachste JavaScript woat fe Brucka mett Eenfach-Skin jelode */',
'modern.js'      => '/* Daut neachste JavaScript woat fe Brucka mett Modern-Skin jelode. */',

# Metadata
'nodublincore'      => 'Dublin-Core-RDF-Metadote send fe disem Server nich aktiv.',
'nocreativecommons' => 'Creative-Commons-RDF-Metadote send fe disem Server nich aktiv.',
'notacceptable'     => 'Dee Wiki-Server kaun dee Dote nich soo reedmoake, daut dien Jereetschauft dee lese kaun.',

# Attribution
'anonymous'        => 'Onbekaunda Brucka {{PLURAL:$1|user|users}} von {{SITENAME}}',
'siteuser'         => '{{SITENAME}}-Brucka $1',
'lastmodifiedatby' => "Dise Sied word daut latste Mol aum $1, Klock $2 von $3 je'endat.",
'othercontribs'    => 'Oppe Gruntloag vonne Oabeit von $1.',
'others'           => 'aundre',
'siteusers'        => '{{SITENAME}}-{{PLURAL:$2|user|users}} $1',
'creditspage'      => 'Siede-Informatioone',
'nocredits'        => 'Fe dise Sied send tjeene Informatioone to habe.',

# Spam protection
'spamprotectiontitle' => 'Spamschutzfilta',
'spamprotectiontext'  => 'Dee Sied, woone du bewoare wullst, word vom Spamschutzfilta blockiet.
Daut woat aun eenem Link lidje, woona no eene externe Sied wiest.',
'spamprotectionmatch' => 'Dee foljenda Tatjst word vom Spamfilta jefunge: $1',
'spambot_username'    => 'MediaWiki Spam-Uborka (Opprieme)',
'spam_reverting'      => 'Latste Versioon ohne Links no $1 wada trajcht jemoakt.',
'spam_blanking'       => 'Aule Versioone haude Links no $1, reed jemoakt',

# Info page
'infosubtitle'   => 'Siedeinformatioon',
'numedits'       => 'Zohl von Endanisse (Sied): $1',
'numtalkedits'   => 'Zohl von Endanisse (Diskussioonssied): $1',
'numwatchers'    => 'Zohl von Beoobachta: $1',
'numauthors'     => 'Zohl von Autore (Sied): $1',
'numtalkauthors' => 'Zohl von Autore (Diskussioonssied): $1',

# Math options
'mw_math_png'    => 'Emma aus PNG wiese',
'mw_math_simple' => 'HTML es zimlich eenfach, sonst PNG',
'mw_math_html'   => 'Wan meajlich aus HTML wiese, sonst PNG',
'mw_math_source' => 'Aus TeX lote (fe Tatjstbrowser)',
'mw_math_modern' => 'Goot fe moderne Browser',
'mw_math_mathml' => 'MathML wan meajlich (experimental)',

# Patrolling
'markaspatrolleddiff'   => 'Aus kontrolliet markere',
'markaspatrolledtext'   => 'Dise Sied aus kontrolliet markere',
'markedaspatrolled'     => 'Aus kontrolliet markiet',
'markedaspatrolledtext' => 'Dee utjewehlde Sied-Versioon es aus kontrolliet markiet.',

# Bad image list
'bad_image_list' => 'Format:

Bloos items, woone mett eenem * aunfange, woare jenome. Dee eschta Link no dem * mott een Link opp een schlajchtet Dokument (file) senne. Dee Links, woone dan kome, wiese opp Utnohme, aulsoo soone Siede, woo daut Dokument (file) jewese en jeseene woare kaun.',

# Metadata
'metadata' => 'Meta-Dote',

# 'all' in various places, this might be different for inflected languages
'watchlistall2' => 'aule',
'namespacesall' => 'aule',
'monthsall'     => 'aule',

# Special:SpecialPages
'specialpages' => 'Spezialsiede',

);
